pub fn evaluate_predictor(traces: &[Trace], lr: f64, l2: f64) -> PredictorEvalExpand description
Run the prequential predictor evaluation over traces with the given lr/l2.
pub fn evaluate_predictor(traces: &[Trace], lr: f64, l2: f64) -> PredictorEvalRun the prequential predictor evaluation over traces with the given lr/l2.