pub enum Reaction {
None,
Demoted(GuardrailVerdict),
Alarmed(GuardrailVerdict),
}Expand description
What happened when an outcome was recorded.
Variants
None
Nothing to do.
Demoted(GuardrailVerdict)
The route just breached and has been demoted to observe.
Alarmed(GuardrailVerdict)
The route just breached and the operator asked only to be told.